<?php
namespace app\daohang\controller;

use app\common\controller\Api;

class Data extends Api
{
    protected $auth = [
         'check'       => true,
         'none_login'  => ['daohang/data/login'],
         'none_right'  => [],
         'error_login' => 'daohang/data/login',
         'error_right' => 'user/center/index',
    ];
    
    public function _initialize()
    {
		parent::_initialize();
    }
    
    //login
    public function login()
    {
        $this->error(lang('empty'));
    }
    
    //分类列表接口
    //category?controll=web|mp|mini
    public function category()
    {
        $item = daohangCategorySelect([
            'cache'    => true,
            'status'   => 'normal',
            'result'   => 'array',
            'limit'    => 0,
            'page'     => 0,
            'sort'     => 'term_id',
            'order'    => 'asc',
            'with'     => '',
            'field'    => 'term_id,term_name,term_slug,term_module,term_controll,term_action',
            'controll' => input('request.controll/s','web'),
            'action'   => 'index',
        ]);
        foreach($item as $key=>$value){
            unset($item[$key]['term_status_text']);
        }
        $this->success(lang('success'),$item);
    }
    
    //内容列表接口
    //detail?controll=web|mp|mini&termId=1&pageNumber=1
    public function detail()
    {
        //初始参数
        $args = [
            'cache'      => true,
            'status'     => 'normal',
            'controll'   => input('request.controll/s','web'),
            'sort'       => 'info_update_time',
            'order'      => daohangSortOrder(input('request.sortOrder/s','asc')),
            'limit'      => 10,
            'page'       => input('request.pageNumber/d',1),
            'with'       => 'info_meta,term,term_map',
            'field'      => 'info_id,info_name,info_slug,info_module,info_controll,info_action,info_excerpt,info_content,info_create_time,info_update_time,info_order,info_type,info_views,info_hits',
        ];
        //分类筛选参数
        if($this->query['termId']){
            $args['controll'] = ['in',['web','mp','mini']];
            $args['term_id'] = intval($this->query['termId']);
            $args['field']   = 'info.info_id,info_name,info_slug,info_module,info_controll,info_action,info_excerpt,info_content,info_create_time,info_update_time,info_order,info_type,info_views,info_hits';
        }
        //数据查询
        if(!$item = daohangSelect($args)){
            $this->error(lang('empty'));
        }
        //重新组合数据
        $json = [];
        $json['total']        = $item['total'];
        $json['per_page']     = $item['per_page'];
        $json['current_page'] = $item['current_page'];
        $json['last_page']    = $item['last_page'];
        $json['list']         = [];
        //拼装数据
        foreach($item['data'] as $key=>$value){
            $json['list'][$key] = $this->detailValue($value);
        }
        unset($item);
        //返回数据
        $this->success(lang('success'),$json);
    }
    
    //单个内容详情接口
    public function index()
    {
        $ids = explode(',',input('request.id/s',1));
        //限制大小
        if(count($ids) > 30){
            $this->error(lang('errorIds'));
        }
        //查询数据
        $item = daohangSelect([
            'cache'      => true,
            'status'     => 'normal',
            'id'         => ['in',$ids],
            'sort'       => 'info_id',
            'order'      => 'asc',
            'with'       => 'info_meta,term,term_map',
            'field'      => 'info_id,info_name,info_slug,info_module,info_controll,info_action,info_excerpt,info_content,info_create_time,info_update_time,info_order,info_type,info_views,info_hits',
            'controll'   => ['in',['web','mp','mini']],
        ]);
        if(!$item){
            $this->error(lang('empty'));
        }
        //拼装数据
        foreach($item as $key=>$value){
            $item[$key] = $this->detailValue($value);
        }
        $this->success(lang('success'),$item);
    }
    
    //内容详情格式化
    private function detailValue($value=[])
    {
        unset($value['category']);
        unset($value['tag']);
        unset($value['term_map']);
        unset($value['info_keywords']);
        unset($value['info_description']);
        unset($value['info_mime_type']);
        unset($value['info_status_text']);
        //图标
        $value['image_ico']   = daohangUrlImage($value['image_ico']);
        //封面
        if(isset($value['image_level'])){
            $value['image_level'] = daohangUrlImage($value['image_level']);
        }
        //二维码
        if(isset($value['image_qrcode'])){
            $value['image_qrcode'] = daohangUrlImage($value['image_qrcode']);
        }
        //截图
        if(isset($value['image_screen'])){
            $value['image_screen'] = explode(';',$value['image_screen']);
            foreach($value['image_screen'] as $key2=>$screen ){
                $value['image_screen'][$key2] = daohangUrlImage($screen);
            }
            //$value['image_screen'] = daohangUrlImage($value['image_screen']);
        }
        //来源处理
        if( $value['info_controll'] != 'web' ){
            $value['info_referer'] = '';
        }
        $value['info_referer'] = DcEmpty($value['info_referer'],$this->site['domain'].'/daohang/info/id/'.$value['info_id']);
        //拼装数据
        return $value;
    }
    
}