<?php
namespace app\daohang\controller;

use app\common\controller\Front;

class Filter extends Front
{
    //继承上级
    public function _initialize()
    {
        //请求过滤
        $this->request->filter('trim,strip_tags,htmlspecialchars');
        //继承上级
        parent::_initialize();
        //请求限制
        if( !$this->indexRequest() ){
            $this->error(lang('dh_error_rest'), 'daohang/index/index');
        }
    }
    
    //按条件筛选页
    public function index()
    {
        //固定参数
        $info = [];
        if( in_array($this->query['controll'],['web','mini','mp']) ){
            $info['controll'] = $this->query['controll'];
        }else{
            $info['controll']   = 'web';
        }
        $info['termId']     = intval($this->query['termId']);
        $info['termSlug']   = str_replace('termSlug','',$this->query['termSlug']);
        $info['termName']   = str_replace('termName','',$this->query['termSlug']);
        $info['pageSize']   = daohangLimit($this->query['pageSize']);
        $info['pageNumber'] = DcEmpty($this->query['pageNumber'], $this->site['page']);
        $info['sortName']   = daohangSortName($this->query['sortName'], 'info_update_time');
        $info['sortOrder']  = daohangSortOrder($this->query['sortOrder'], 'desc');
        //筛选参数
        $info['pageFilter'] = DcArrayEmpty($info);
        //分页PATH
        $info['pagePath']   = daohangUrlFilter( array_merge($info['pageFilter'],['pageNumber'=>'[PAGE]']) );
        //分页重置
        $info['pageReset']  = daohangUrlFilter([
            'controll'   => $info['controll'],
            'termId'     => 0,
            'pageSize'   => 10,
            'pageNumber' => 1,
            'sortName'   => 'info_id',
            'sortOrder'  => 'desc'
        ]);
        //数据查询参数
        $args = [];
        $args['cache']    = true;
        $args['status']   = 'normal';
        $args['controll'] = ['eq',$info['controll']];
        $args['limit']    = $info['pageSize'];
        $args['page']     = $info['pageNumber'];
        $args['sort']     = $info['sortName'];
        $args['order']    = $info['sortOrder'];
        //自定义字段排序
        if( in_array($args['sort'],['info_up','info_down']) ){
            $args['meta_key'] = $args['sort'];
            $args['sort']     = 'meta_value_num';
        }
        //分类ID限制
        if($info['termId']){
            $args['term_id'] = ['eq',intval($info['termId'])];
        }
        //分类别名限制
        if($info['termSlug']){
            $args['term_slug'] = ['eq',$info['termSlug']];
        }
        //分类名称限制
        if($info['termName']){
            $args['term_name'] = ['eq',$info['termName']];
        }
        //数据查询
        $info['list'] = daohangSelect($args);
        //URL参数
        $info['query'] = DcArrayEmpty($this->query);
        //筛选列表
        $info['controlls'] = [
            'web'  => lang('dh_option_web'),
            'mp'   => lang('dh_option_mp'),
            'mini' => lang('dh_option_mini'),
        ];
        $info['pageSizes'] = [
            '10'  => 10,
            '20'  => 20,
            '30'  => 30,
            '50'  => 50,
            '100' => 100,
        ];
        $info['sortNames'] = [
            'info_views'       => lang('info_views'),
            'info_update_time' => lang('info_update_time'),
            'info_order'       => lang('info_order'),
            'info_up'          => lang('dh_up'),
            'info_id'          => 'ID',
        ];
        $info['sortOrders'] = [
            'desc' => lang('dh_desc'),
            'asc'  => lang('dh_asc'),
        ];
        //当前模型所有分类
        $terms = daohangCategorySelect([
            'cache'    => true,
            'status'   => 'normal',
            'result'   => 'array',
            'controll' => $info['controll'],
            'action'   => 'index',
            'field'    => 'term_id,term_slug,term_name',
            'with'     => '',
            'limit'    => 0,
            'page'     => 0,
            'sort'     => 'term_count desc,term_id',
            'order'    => 'desc',
        ]);
        foreach($terms as $key=>$value){
            $info['termIds'][$value['term_id']] = $value['term_name'];
            $info['termSlugs'][$value['term_slug']] = $value['term_name'];
        }
        //当前分类或标签
        if( $info['termId'] ){
            $term = daohangCategoryId($info['termId']);
        }elseif( $info['termSlug'] ){
            $term = daohangCategorySlug($info['termSlug']);
        }elseif( $info['termName'] ){
            $term = daohangCategoryName($info['termName']);
        }
        //变量赋值
        $this->assign($info);
        $this->assign($term);
        //加载模板
        return $this->fetch($info['controll']);
    }
    
    //搜索请求是否合法（间隔睦长）
    private function indexRequest()
    {
        //未开启请求限制
        if( !config('daohang.request_max') ){
            return true;
        }
        //请求限制白名单
        if ( \daicuo\Auth::check('daohang/filter/index', $this->site['user']['user_capabilities'], $this->site['user']['user_caps']) ) {
            return true;
        }
        //客户端唯一标识 $_SERVER["HTTP_REFERER"]
        $requestClient = md5($this->request->ip().$this->request->header('user-agent'));
        //60秒内最大请求次数
        $requestMax = intval(DcCache('request'.$requestClient));
        if($requestMax > config('daohang.request_max')){
            return false;
        }
        DcCache('request'.$requestClient, $requestMax+1, 60);
        //默认返回
        return true;
    }
}